<?php

/**
 * The Factory frontend class.
 * This class controls which concrete Factory
 * will be used, depending on the current
 * 'security mode'. It lazy instantiates both
 * factories (process and module) when they are
 * required, and stores these objects. All the
 * accesses to factories are done through this class,
 * implementing a kind of Proxy design pattern.
 * This class depends on Security frontend class
 * to decide which factory to call.
 *
 * @author Pedro Eugênio Rocha
 * @package Factory
 * @static
 */
class Factory {


	/**
	 * @var object $_unsecuredFactory Stores WorkflowFactory object.
	 * @access private
	 * @static
	 */
	private static $_unsecuredFactory = null;


	/**
	 * @var object $_securedFactory Stores ProcessFactory object.
	 * @access private
	 * @static
	 */
	private static $_securedFactory = null;


	/**
	 * Constructor. Just disable direct instantiation.
	 *
	 * @access public
	 * @return void
	 * @static
	 */
	public function __construct() {
		throw new Exception("Oops! Static only class.");
	}


	/**
	 * Just forward this call to the correct class.
	 *
	 * @access public
	 * @retun object
	 * @static
	 */
	public static function getInstance() {

		/* oops. we are in the process space. */
		if (Security::isEnabled()) {

			/* must instatiate it */
			if (is_null(self::$_securedFactory))
				self::$_securedFactory = new ProcessFactory();

			$args = func_get_args();
			call_user_func_array(array(self::$_securedFactory, "getInstance"), $args);

		}
		/* regular module space */
		else {

			/* must instatiate it */
			if (is_null(self::$_unsecuredFactory))
				self::$_unsecuredFactory = new WorkflowFactory();

			$args = func_get_args();
			call_user_func_array(array(self::$_unsecuredFactory, "getInstance"), $args);
		}

	}


	/**
	 * Just forward this call to the correct class.
	 *
	 * @todo I must implement it!
	 * @access public
	 * @retun object
	 * @static
	 */
	public static function newInstance() {
	}
}

?>
