<?php

/**
 * Specialization of the BaseFactory class.
 * This class is used to instantiate classes for
 * processes. You cannot access this class directly,
 * but requests to the Factory frontend class in
 * 'secured mode' will be forwarded to this class.
 * It should be much more restrictive than its
 * older brother (or sister), WorkflowFactory...
 *
 * @author Pedro Eugênio Rocha
 * @package Factory
 */
final class ProcessFactory extends BaseFactory {


	/**
	 * @var boolean $_instantiated Attribute that stores whether this
	 *		class was instantiated or not. This is used to limit the
	 * 		instantiation of this class.
	 * @access private
	 * @static
	 */
	private static $_instantiated = false;

	/**
	 * Construct the class. This function will inform which classes
	 * you will be able to instantiate and where to find it.
	 * This function implements a kind of singleton design pattern too.
	 * @access public
	 */
	public function __construct() {

		/* don't let the user to instantiate this class more than once. */
		if (self::$_instantiated)
			throw new Exception("You can't instantiate this class again.");

		/* registering allowed classes */
		//$this->registerFileInfo('WorkflowObjects', 'class.WorkflowObjects.inc.php', 'inc');

		/* ok. no more instances of this class.. */
		self::$_instantiated = true;
	}
}

?>
